<?php

namespace Drupal\monarch_migration;

use Drupal\migrate\Row;
use Drupal\migrate\Plugin\MigrationInterface;

/**
 * Defines the interface for a migration mapper plugin.
 */
interface MigrationMapperInterface {

  /**
   * The prepareRow event.
   *
   * @param \Drupal\migrate\Row $row
   *   The migration row.
   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
   *   The migration.
   */
  public function prepareRow(Row $row, MigrationInterface $migration);

  /**
   * The postProcess event.
   *
   * @param \Drupal\migrate\Row $row
   *   The migration row.
   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
   *   The migration.
   */
  public function postProcess(Row $row, MigrationInterface $migration);

  /**
   * The preRowSave event.
   *
   * @param \Drupal\migrate\Row $row
   *   The migration row.
   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
   *   The migration.
   */
  public function preRowSave(Row $row, MigrationInterface $migration);

  /**
   * The postRowSave event.
   *
   * @param \Drupal\migrate\Row $row
   *   The migration row.
   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
   *   The migration.
   */
  public function postRowSave(Row $row, MigrationInterface $migration);

  /**
   * The get the migration ids.
   */
  public function getMigrations() : array;

  /**
   * Does this plugin apply to the specified migration?
   */
  public function isApplicable(string $migration_id);

  /**
   * Get the plugin weight.
   */
  public function getWeight();

}
